@@ -14,7 +14,7 @@ class CHPLPGSystemConfig(ModelConfig):
         self.house = HeatDemandConfig(params["household"])
         self.chp = CHPLPGConfig(params["chp"])
 
-        self._default_schedule = self.chp.default_schedule
+        self.default_schedule = self.chp.default_schedule
 
     @property
     def p_min_kw(self):
