@@ -3,7 +3,7 @@ from datetime import datetime, timedelta
 
 import numpy as np
 import pandas as pd
-from pysimmods.util.dateformat import GER, TZ
+from pysimmods.util.date_util import GER, TZ
 
 from .forecast_model import ForecastModel
 
@@ -11,6 +11,12 @@ from .forecast_model import ForecastModel
 class FlexibilityModel(ForecastModel):
     """The flexibility model for all pysimmods."""
 
+    def __init__(self):
+        if seed is not None:
+            self._rng = np.random.RandomState(seed)
+        else:
+            self._rng = np.random.RandomState()
+
     def generate_schedules(self, start, forecast_horizon_hours, num_schedules):
         """Perform sampling and generate a set of schedules for the
         specified time interval.
