@@ -1,5 +1,6 @@
 """This module contains the config model for the inverter."""
 from pysimmods.model.config import ModelConfig
+from pysimmods.model.qgenerator import QControl
 
 
 class InverterConfig(ModelConfig):
@@ -32,11 +33,8 @@ class InverterConfig(ModelConfig):
     def __init__(self, params):
         super().__init__(params)
 
-        self.sn_kva = params["sn_kva"]
+        self.s_max_kva = params["sn_kva"]
         self._controls = ["p_set", "q_set", "cos_phi_set", "pq_set", "qp_set"]
-        self.q_control = params.get("q_control", self._controls[0])
-        if self.q_control not in self._controls:
-            self.q_control = self._controls[0]
-
+        self.q_control = QControl[params.get("q_control", "p_set").upper()]
         self.cos_phi = params.get("cos_phi", 0.9)
         self.inverter_mode = params.get("inverter_mode", "capacitive")
